@@ -416,7 +416,7 @@ void DatabaseManager::reset () {
 		QSqlQuery query (db);
 		ret |= query.exec("drop table id");
 		ret |= query.exec("drop table targets");
-		ret |= query.exec("drop table fieds");
+		ret |= query.exec("drop table fields");
 		ret |= query.exec("drop table softwareVersion");
 	}
 
@@ -510,6 +510,8 @@ bool DatabaseManager::openDB(const QString & pas) {
 			currentVersion = 1;
 		}
 
+		//qDebug() << "init db with pas taules "<< db.tables().count();
+
 		if (db.tables().count() != 4) {
 			initdb = false;
 			currentVersion = SOFT_VERSION;
