@@ -56,6 +56,9 @@ void QLabelZ::paintEvent(QPaintEvent* event)
    	QLabel::paintEvent(event);
 }
 
+void LoginDialog::focus () {
+	label->setFocus ();
+}
 LoginDialog::LoginDialog(bool firstTime, eWallet *paTarget): QWidget((QWidget*)paTarget)
 {
 	setContextMenuPolicy(Qt::NoContextMenu);
