@@ -1380,7 +1380,7 @@ void eWallet::duplicateTarget (Target * target) {
 	dbManager->getFields(target);
 
 	if (detailWindowEdit.isNull()) {
-		detailWindowEdit = new DetailWindow(target, *currentGroup, 2, true, this, this);
+		detailWindowEdit = new DetailWindow(target, currentGroup != NULL ? *currentGroup : "", 2, true, this, this);
 		//detailWindowEdit->setAttribute(Qt::WA_Maemo5StackedWindow);
         detailWindowEdit->setAttribute(Qt::WA_DeleteOnClose);
         connect(detailWindowEdit, SIGNAL(destroyed(QObject*)),
@@ -1393,7 +1393,7 @@ void eWallet::newLikeTarget (Target * target) {
 	dbManager->getFields(target);
 
 	if (detailWindowEdit.isNull()) {
-		detailWindowEdit = new DetailWindow(target, *currentGroup, 1, true, this, this);
+		detailWindowEdit = new DetailWindow(target, currentGroup != NULL ? *currentGroup : "", 1, true, this, this);
 		//detailWindowEdit->setAttribute(Qt::WA_Maemo5StackedWindow);
         detailWindowEdit->setAttribute(Qt::WA_DeleteOnClose);
         connect(detailWindowEdit, SIGNAL(destroyed(QObject*)),
@@ -1404,7 +1404,7 @@ void eWallet::newLikeTarget (Target * target) {
 
 void eWallet::newTarget() {
 	if (detailWindowEdit.isNull()) {
-		detailWindowEdit = new DetailWindow(NULL, *currentGroup, 0, true, this, this);
+		detailWindowEdit = new DetailWindow(NULL, currentGroup != NULL ? *currentGroup : "", 0, true, this, this);
 		//detailWindowEdit->setAttribute(Qt::WA_Maemo5StackedWindow);
         detailWindowEdit->setAttribute(Qt::WA_DeleteOnClose);
         connect(detailWindowEdit, SIGNAL(destroyed(QObject*)),
